@@ -1,7 +1,7 @@
 import datetime
-from dataclasses import dataclass, field
-from types import FunctionType, TracebackType
-from typing import Any, Dict, List, Set, Tuple, Union
+from dataclasses import asdict, dataclass, field
+from types import TracebackType
+from typing import Any, Callable, Dict, List, Set, Tuple, Union
 from uuid import UUID, uuid4
 
 from roview import rodict, roset
@@ -27,6 +27,11 @@ from arrlio.settings import (
 
 @dataclass
 class TaskData:
+    """
+    Args:
+        meta (dict, optional): additional task functionc keyworad argument.
+    """
+
     task_id: UUID = field(default_factory=uuid4)
     args: tuple = field(default_factory=tuple)
     kwds: dict = field(default_factory=dict)
@@ -52,10 +57,13 @@ class TaskData:
         if isinstance(self.args, list):
             object.__setattr__(self, "args", tuple(self.args))
 
+    def dict(self):
+        return asdict(self)
+
 
 @dataclass(frozen=True)
 class Task:
-    func: FunctionType
+    func: Callable
     name: str
     bind: bool = TASK_BIND
 
@@ -72,6 +80,12 @@ class Task:
 
     extra: dict = field(default_factory=dict)
 
+    loads: Callable = None
+    dumps: Callable = None
+
+    def dict(self):
+        return {k: v for k, v in asdict(self).items() if k not in {"loads", "dumps"}}
+
     def instantiate(self, extra: dict = None, **kwds) -> "TaskInstance":
         data: TaskData = TaskData(
             **{
@@ -111,6 +125,9 @@ class TaskInstance:
             args = (self,) + args
         return self.task.func(*args, **kwds)
 
+    def dict(self):
+        return {"task": self.task.dict(), "data": self.data.dict()}
+
 
 @dataclass(frozen=True)
 class TaskResult:
@@ -119,6 +136,9 @@ class TaskResult:
     trb: Union[TracebackType, str] = None
     routes: Union[str, List[str]] = None
 
+    def dict(self):
+        return asdict(self)
+
 
 @dataclass(frozen=True)
 class Message:
@@ -130,6 +150,9 @@ class Message:
     ack_late: bool = MESSAGE_ACK_LATE
     extra: dict = field(default_factory=dict)
 
+    def dict(self):
+        return asdict(self)
+
 
 @dataclass(frozen=True)
 class Event:
@@ -147,14 +170,17 @@ class Event:
         elif isinstance(self.dt, str):
             object.__setattr__(self, "dt", datetime.datetime.fromisoformat(self.dt))
 
+    def dict(self):
+        return asdict(self)
+
 
 class Graph:
     def __init__(
         self,
-        id: str,
-        nodes: dict = None,
-        edges: dict = None,
-        roots: set = None,
+        id: str,  # pylint: disable=redefined-builtin
+        nodes: Dict = None,
+        edges: Dict = None,
+        roots: Set = None,
     ):
         self.id = id
         self.nodes: Dict[str, List[str]] = rodict({}, nested=True)
