@@ -2,18 +2,20 @@ import importlib
 import json
 import logging
 import traceback
-from dataclasses import asdict
 from typing import Any
 
-from arrlio import __tasks__
+from arrlio.core import __tasks__
 from arrlio.models import Event, Graph, Task, TaskInstance, TaskResult
 from arrlio.serializers.base import Serializer
 from arrlio.utils import ExtendedJSONEncoder
 
 logger = logging.getLogger("arrlio.serializers.json")
 
+json_dumps = json.dumps
+json_loads = json.loads
 
-class Serializer(Serializer):
+
+class Serializer(Serializer):  # pylint: disable=function-redefined
     def __init__(self, encoder=None):
         self.encoder = encoder or ExtendedJSONEncoder
 
@@ -21,11 +23,11 @@ class Serializer(Serializer):
         return "json.Serializer"
 
     def dumps_task_instance(self, task_instance: TaskInstance, **kwds) -> bytes:
-        dct = asdict(task_instance)
+        dct = task_instance.dict()
         data = dct["data"]
         if graph := data["graph"]:
             data["graph"] = graph.dict()
-        return json.dumps(
+        return json_dumps(
             {
                 "name": dct["task"]["name"],
                 **{k: v for k, v in data.items() if v is not None},
@@ -34,7 +36,7 @@ class Serializer(Serializer):
         ).encode()
 
     def loads_task_instance(self, data: bytes) -> TaskInstance:
-        data = json.loads(data)
+        data = json_loads(data)
         if data.get("graph"):
             data["graph"] = Graph.from_dict(data["graph"])
         name = data.pop("name")
@@ -63,14 +65,14 @@ class Serializer(Serializer):
         result_data = json.loads(data)
         if exc := result_data[1]:
             try:
-                m = importlib.import_module(exc[0])
-                result_data[1] = getattr(m, exc[1])(exc[2])
+                module = importlib.import_module(exc[0])
+                result_data[1] = getattr(module, exc[1])(exc[2])
             except Exception:
                 pass
         return TaskResult(*result_data)
 
     def dumps_event(self, event: Event, **kwds) -> bytes:
-        data = asdict(event)
+        data = event.dict()
         return json.dumps(data, cls=self.encoder).encode()
 
     def loads_event(self, data: bytes) -> Event:
